/*
  Macro           Test_MarkStream_with_GetMarkedText
  Author          Carlo Hogeveen
  Website         eCarlo.nl/tse
  Compatibility   Windows TSE v4 upwards,
                  except some old, irrelevant beta versions of TSE.
  Version         v1   22 Apr 2024


  This test macro demonstartes how MarkStream() works with
    GetMarkedText()

  The RemoveTrailingWhite setting is temporarily set to OFF,
  so that end-of-line spaces are never automatically removed.

  What I noticed:
  - GetMarkedText() consistently ignores "characters" that MarkStream() marks
    past the end of a line; across all TSE versions from TSE v4 upwards.

  This macro's purpose is just to show how MarkStream() and TSE's
  GetMarkedText() commands work together.

  It is neither a request for change nor an objection to change.

*/


proc Main()
  integer i                       = 0
  integer old_RemoveTrailingWhite = Set(RemoveTrailingWhite, OFF)
  integer old_SpecialEffects      = Query(SpecialEffects)
  integer tmp_id                  = 0

  #if EDITOR_VERSION >= 4400h
    Set(SpecialEffects, Query(SpecialEffects) | _CENTER_POPUPS_)
  #endif
  #ifndef INTERNAL_VERSION        // TSE v4.41.44, 18 Jan 2021.
    #define INTERNAL_VERSION 0
  #endif
  #if INTERNAL_VERSION >= 12369   // TSE v4.50rc7, 29 Jul 2023.
    Set(SpecialEffects, Query(SpecialEffects) & (MAXINT ^ _TOP_RT_POPUPS_))
  #endif

  SetWindowTitle(Format(INTERNAL_VERSION))

  PushLocation()
  tmp_id = NewFile()
  InsertText('hello world')

  UnMarkBlock()
  BegLine()
  MarkStream()
  EndLine()
  UpdateDisplay(_ALL_WINDOWS_REFRESH_)
  Warn('Test 0: "', GetMarkedText(), '".')

  for i = 1 to 13
    UnMarkBlock()
    BegLine()
    MarkStream()
    GotoColumn(i)
    MarkStream()
    UpdateDisplay(_ALL_WINDOWS_REFRESH_)
    Warn('Test'; i, ': "', GetMarkedText(), '".')
  endfor

  PopLocation()
  AbandonFile(tmp_id)
  Set(RemoveTrailingWhite, old_RemoveTrailingWhite)
  Set(SpecialEffects     , old_SpecialEffects)
  PurgeMacro(CurrMacroFilename())
end Main

